@@ -29,6 +29,12 @@ INTERNALERROR_INTERNALERROR = 'InternalError.InternalError'
 # 参数错误。
 INVALIDPARAMETER = 'InvalidParameter'
 
+# 图片长宽比太大
+INVALIDPARAMETER_IMAGEASPECTRATIOTOOLARGE = 'InvalidParameter.ImageAspectRatioTooLarge'
+
+# 图片体积太小
+INVALIDPARAMETER_IMAGEDATATOOSMALL = 'InvalidParameter.ImageDataTooSmall'
+
 # 图片分辨率过低。
 INVALIDPARAMETER_IMAGESIZETOOSMALL = 'InvalidParameter.ImageSizeTooSmall'
 
@@ -50,7 +56,7 @@ INVALIDPARAMETERVALUE_IMAGESIZETOOSMALL = 'InvalidParameterValue.ImageSizeTooSma
 # 回调地址错误。
 INVALIDPARAMETERVALUE_INVALIDCALLBACKURL = 'InvalidParameterValue.InvalidCallbackUrl'
 
-# FileContent和FileUrl为空。
+# FileContent和FileUrl为空或base64编码错误。
 INVALIDPARAMETERVALUE_INVALIDCONTENT = 'InvalidParameterValue.InvalidContent'
 
 # DataId格式错误。
